package com.winhc.bigdata.flink.func

import com.winhc.bigdata.flink.config.HbaseConfig
import com.winhc.bigdata.flink.implicits._
import org.apache.flink.configuration.Configuration
import org.apache.flink.streaming.api.scala.async.{ResultFuture, RichAsyncFunction}
import org.apache.hadoop.hbase.TableName
import org.apache.hadoop.hbase.client.{Connection, ConnectionFactory, Get}

/**
 * @author: XuJiakai
 * @date: 2021/8/31 17:07
 */
case class HbaseAsyncFunction() extends RichAsyncFunction[(String, String), (String, String, String)] {
  var connection: Connection = null

  override def open(parameters: Configuration): Unit = {
    val configuration = HbaseConfig.getHbaseConfiguration()
    connection = ConnectionFactory.createConnection(configuration)
  }

  override def asyncInvoke(input: (String, String), resultFuture: ResultFuture[(String, String, String)]): Unit = {
    val tn = input._1
    val rowkey = input._2
    try {
      val table = connection.getTable(TableName.valueOf(tn.toUpperCase()))
      val get = new Get(rowkey.getBytes)
      val result = table.get(get)
      val string = result.toJsonString
      resultFuture.complete(Seq((tn, rowkey, string)))
    } catch {
      case ex: Exception => {
        resultFuture.completeExceptionally(ex)
      }
    }
  }
  //  override def timeout(input: (String, String), resultFuture: ResultFuture[(String, String, String)]): Unit = {
  //
  //  }

  override def close(): Unit = {
    if (connection != null) {
      connection.close()
    }
  }
}
